summaryrefslogtreecommitdiffstats
path: root/interfaces/kscript/scriptinterface.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:46:43 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:46:43 +0000
commitffe8a83e053396df448e9413828527613ca3bd46 (patch)
treea73d4169e02df4a50f9a12cb165fcd0ab5bac7c6 /interfaces/kscript/scriptinterface.h
parent682bf3bfdcbcbb1fca85e8a36ed03e062e0555d5 (diff)
downloadtdelibs-ffe8a83e053396df448e9413828527613ca3bd46.tar.gz
tdelibs-ffe8a83e053396df448e9413828527613ca3bd46.zip
Trinity Qt initial conversion
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdelibs@1157647 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'interfaces/kscript/scriptinterface.h')
-rw-r--r--interfaces/kscript/scriptinterface.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/interfaces/kscript/scriptinterface.h b/interfaces/kscript/scriptinterface.h
index de387ecc6..9ca3a45bd 100644
--- a/interfaces/kscript/scriptinterface.h
+++ b/interfaces/kscript/scriptinterface.h
@@ -27,8 +27,8 @@
**/
#ifndef __scriptinterface_h__
#define __scriptinterface_h__
-#include <qvariant.h>
-#include <qobject.h>
+#include <tqvariant.h>
+#include <tqobject.h>
#include <kdemacros.h>
//#include <scripclientinterface.h>
@@ -50,25 +50,25 @@ class KScriptClientInterface;
public:
/**
* Return the current script code data
* @returns QString containing the currenly runable code
**/
- virtual QString script() const = 0;
+ virtual TQString script() const = 0;
/**
* Sets the path to the script library that we are going to embed.
**/
- virtual void setScript( const QString &scriptFile ) = 0;
+ virtual void setScript( const TQString &scriptFile ) = 0;
/**
* Sets the path to the script library that we are going to embed.
* The second argument is the function from the script library that
* we wish to call.
**/
- virtual void setScript( const QString &scriptLibFile, const QString &method ) = 0;
+ virtual void setScript( const TQString &scriptLibFile, const TQString &method ) = 0;
/**
* Run the actual script code
* This can both take a context object that will be shared between the
* main application and a variant that will contain the arguments.
**/
- virtual void run(QObject *context = 0, const QVariant &arg = 0) = 0;
+ virtual void run(TQObject *context = 0, const TQVariant &arg = 0) = 0;
/**
* Abort the scripts run
**/
@@ -50,25 +50,25 @@ class KScriptClientInterface;
/**
* Return the current script code data
- * @returns QString containing the currenly runable code
+ * @returns TQString containing the currenly runable code
**/